HttpDouble.Application (http_double v1.0.0)

Copy Markdown View Source

OTP application entry point for :http_double.

The application itself is intentionally minimal – it only starts a Registry used for optional server naming. Individual HTTP dummy servers are started via HttpDouble.start_link/1 or as children under your own supervision tree using HttpDouble.child_spec/1.